@@ -19,24 +19,24 @@ sub new {
     return $this;
 }
 
-sub configValue {
+sub conf {
     my $this = shift();
     my($key, $default) = @_;
     my $val = $this->{$key};
     if (defined $val) {
-	#warn "configValue($key) -> '$val'";
+	#warn "conf($key) -> '$val'";
     } elsif (defined $default) {
 	$val = $default;
-	#warn "configValue($key) undefined, default to '$val'";
+	#warn "conf($key) undefined, default to '$val'";
     } else {
-	#warn "configValue($key) undefined";
+	#warn "conf($key) undefined";
     }
 
     return $val;
 }
 
 # A simple alias for these purposes
-sub option { shift()->configValue(@_) }
+sub option { shift()->conf(@_) }
 
 ### Should really delegate to a separate Log package
 sub log {
